@@ -23,21 +23,21 @@ class ModifyMonitorGroupInstancesRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'ModifyMonitorGroupInstances','cms')
+		self.set_method('POST')
 
 	def get_Instancess(self):
 		return self.get_query_params().get('Instancess')
 
-	def set_Instancess(self,Instancess):
-		for i in range(len(Instancess)):	
-			if Instancess[i].get('InstanceId') is not None:
-				self.add_query_param('Instances.' + str(i + 1) + '.InstanceId' , Instancess[i].get('InstanceId'))
-			if Instancess[i].get('InstanceName') is not None:
-				self.add_query_param('Instances.' + str(i + 1) + '.InstanceName' , Instancess[i].get('InstanceName'))
-			if Instancess[i].get('RegionId') is not None:
-				self.add_query_param('Instances.' + str(i + 1) + '.RegionId' , Instancess[i].get('RegionId'))
-			if Instancess[i].get('Category') is not None:
-				self.add_query_param('Instances.' + str(i + 1) + '.Category' , Instancess[i].get('Category'))
-
+	def set_Instancess(self, Instancess):
+		for depth1 in range(len(Instancess)):
+			if Instancess[depth1].get('InstanceId') is not None:
+				self.add_query_param('Instances.' + str(depth1 + 1) + '.InstanceId', Instancess[depth1].get('InstanceId'))
+			if Instancess[depth1].get('InstanceName') is not None:
+				self.add_query_param('Instances.' + str(depth1 + 1) + '.InstanceName', Instancess[depth1].get('InstanceName'))
+			if Instancess[depth1].get('RegionId') is not None:
+				self.add_query_param('Instances.' + str(depth1 + 1) + '.RegionId', Instancess[depth1].get('RegionId'))
+			if Instancess[depth1].get('Category') is not None:
+				self.add_query_param('Instances.' + str(depth1 + 1) + '.Category', Instancess[depth1].get('Category'))
 
 	def get_GroupId(self):
 		return self.get_query_params().get('GroupId')
